##
##  aom.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_opkg 3.11.0
%define       V_snap 20241031

#   package information
Name:         aom
Summary:      AV1 Video Codec Library
URL:          https://aomedia.googlesource.com/aom/
Vendor:       Alliance for Open Media (AOM)
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Video
License:      MIT
Version:      %{V_opkg}.%{V_snap}
Release:      20241031

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/aom/aom-%{V_snap}.tar.xz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, cmake, gcc, gcc::with_cxx = yes
PreReq:       OpenPKG, openpkg >= 20160101

%description
    AOMedia Video 1 (AV1), is an open, royalty-free video coding format
    designed for video transmissions over the Internet. It is being
    developed by the Alliance for Open Media (AOMedia), a consortium of
    firms from the semiconductor industry, video on demand providers,
    and web browser developers, founded in 2015. AV1 is meant to succeed
    its predecessor VP9 and compete with HEVC/H.265 from the Moving
    Picture Experts Group.

%track
    prog aom:base = {
        version   = %{V_opkg}
        url       = https://aomedia.googlesource.com/aom/
        regex     = tags/v(\d+\.\d+\.\d+)
    }
    prog aom:snap = {
        version   = %{V_snap}
        url       = http://download.openpkg.org/components/versioned/aom/
        regex     = aom-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n aom

%build
    cd build
    cmake \
        -DCMAKE_BUILD_TYPE="Release" \
        -DCMAKE_INSTALL_PREFIX="%{l_prefix}" \
        -DCMAKE_C_COMPILER="%{l_cc}" \
        -DCMAKE_C_FLAGS="%{l_cflags} %{l_cppflags}" \
        -DCMAKE_EXE_LINKER_FLAGS="%{l_ldflags}" \
        -DCMAKE_CXX_COMPILER="%{l_cxx}" \
        -DENABLE_SHARED=OFF \
        -DCONFIG_UNIT_TESTS=OFF \
        -DAOM_TARGET_CPU=generic \
        ..
    %{l_make} %{l_mflags -O}

%install
    (   cd build
        %{l_make} %{l_mflags} install DESTDIR=$RPM_BUILD_ROOT
    ) || exit $?
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

